# remirepo spec file for php-pecl-yaf
#
# Copyright (c) 2012-2024 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-pecl-yaf}

%bcond_without      tests

%global gh_commit   51e458e9746d7061efc565d49baaca26feacd7ff
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    laruence
%global gh_project  yaf
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name   yaf
%global ini_name    40-%{pecl_name}.ini
%global sources     %{pecl_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:       Yet Another Framework
Name:          %{?scl_prefix}php-pecl-yaf
Version:       3.3.6
Release:       4%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:       PHP-3.01
URL:           https://pecl.php.net/package/yaf
Source0:       https://pecl.php.net/get/%{sources}%{?prever}.tgz
Source1:       %{pecl_name}.ini

Patch0:        %{pecl_name}-upstream.patch
Patch1:        0001-remove-trailing-space.patch
Patch2:        0002-relax-test-expectations-for-8.4.patch

BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel >= 7.0
BuildRequires: %{?scl_prefix}php-pear
# for tests
BuildRequires: %{?scl_prefix}php-json

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}

Provides:      %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:      %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:      %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:      %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
The Yet Another Framework (Yaf) extension is a PHP framework that is used
to develop web applications. 

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
%patch -P0 -p1
%patch -P1 -p1
%patch -P2 -p1

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_YAF_VERSION/{s/.*\t"//;s/".*$//;p}' php_yaf.h )
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif


%build
%{?dtsenable}

export CFLAGS="%{optflags} -Wno-duplicate-decl-specifier"

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure --with-php-config=%{__phpconfig}
%make_build

%if %{with_zts}
cd ../ZTS
%configure --with-php-config=%{__ztsphpconfig}
%make_build
%endif


%install
%{?dtsenable}

# Install the NTS stuff
%make_install -C NTS
install -D -m 644 %{SOURCE1} %{buildroot}%{php_inidir}/%{ini_name}

# Install the ZTS stuff
%if %{with_zts}
%make_install -C ZTS
install -D -m 644 %{SOURCE1} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Install the package XML file
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

# Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

OPTS="-n"
[ -f %{php_extdir}/json.so     ] && OPTS="$OPTS -d extension=json.so"

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="$OPTS -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%{php_ztsextdir}/%{pecl_name}.so
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%endif


%changelog
* Tue Nov 26 2024 Remi Collet <remi@remirepo.net> - 3.3.6-4
- drop BR on pcre-devel

* Tue Oct  1 2024 Remi Collet <remi@remirepo.net> - 3.3.6-3
- fix PHP 8.4 build using patch from
  https://github.com/laruence/yaf/pull/594

* Wed Jul 10 2024 Remi Collet <remi@remirepo.net> - 3.3.6-2
- add upstream patch for PHP 8.4

* Mon Jul  1 2024 Remi Collet <remi@remirepo.net> - 3.3.6-1
- update to 3.3.6
- drop patch merged upstream

* Mon Feb 19 2024 Remi Collet <remi@remirepo.net> - 3.3.5-4
- add patch for PHP 7.4 from
  https://github.com/laruence/yaf/pull/579

* Thu Sep 14 2023 Remi Collet <remi@remirepo.net> - 3.3.5-3
- add patch for PHP 8.3 from
  https://github.com/laruence/yaf/pull/579
- build out of sources tree

* Mon Sep 19 2022 Remi Collet <remi@remirepo.net> - 3.3.5-2
- add patch for PHP 8.2 from
  https://github.com/laruence/yaf/pull/579

* Mon May 23 2022 Remi Collet <remi@remirepo.net> - 3.3.5-1
- update to 3.3.5

* Thu Dec 16 2021 Remi Collet <remi@remirepo.net> - 3.3.4-1
- update to 3.3.4
- drop patch merged upstream

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 3.3.3-3
- rebuild for 8.1.0RC1

* Wed Jul 21 2021 Remi Collet <remi@remirepo.net> - 3.3.3-2
- add patch for PHP 8.1.0beta1 from
  https://github.com/laruence/yaf/pull/548

* Thu Jul  1 2021 Remi Collet <remi@remirepo.net> - 3.3.3-1
- update to 3.3.3

* Fri Mar  5 2021 Remi Collet <remi@remirepo.net> - 3.3.2-1
- update to 3.3.2

* Sun Feb 21 2021 Remi Collet <remi@remirepo.net> - 3.3.1-1
- update to 3.3.1

* Wed Jan  6 2021 Remi Collet <remi@remirepo.net> - 3.3.0-1
- update to 3.3.0

* Thu Jun 11 2020 Remi Collet <remi@remirepo.net> - 3.2.5-1
- update to 3.2.5

* Thu Jun  4 2020 Remi Collet <remi@remirepo.net> - 3.2.4-1
- update to 3.2.4

* Sun May 17 2020 Remi Collet <remi@remirepo.net> - 3.2.3-1
- update to 3.2.3

* Mon May 11 2020 Remi Collet <remi@remirepo.net> - 3.2.2-1
- update to 3.2.2

* Mon Apr 20 2020 Remi Collet <remi@remirepo.net> - 3.2.1-1
- update to 3.2.1

* Sun Apr 19 2020 Remi Collet <remi@remirepo.net> - 3.2.0-1
- update to 3.2.0 (beta)
- open https://github.com/laruence/yaf/pull/474
  relax test, don't rely on sources path

* Wed Apr  1 2020 Remi Collet <remi@remirepo.net> - 3.1.4-1
- update to 3.1.4

* Fri Mar 20 2020 Remi Collet <remi@remirepo.net> - 3.1.3-1
- update to 3.1.3

* Tue Mar 17 2020 Remi Collet <remi@remirepo.net> - 3.1.2-1
- update to 3.1.2

* Mon Mar 16 2020 Remi Collet <remi@remirepo.net> - 3.1.1-1
- update to 3.1.1

* Sun Mar 15 2020 Remi Collet <remi@remirepo.net> - 3.1.0-1
- update to 3.1.0

* Thu Dec 19 2019 Remi Collet <remi@remirepo.net> - 3.0.9-1
- update to 3.0.9

* Mon Dec 10 2018 Remi Collet <remi@remirepo.net> - 3.0.8-1
- update to 3.0.8

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 3.0.7-4
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 3.0.7-3
- rebuild for 7.3.0alpha4 new ABI
- add patch for 7.3.0 from
  https://github.com/laruence/yaf/pull/410

* Thu Jun 28 2018 Remi Collet <remi@remirepo.net> - 3.0.7-2
- add upstream patch for PHP 7.3

* Thu Mar 22 2018 Remi Collet <remi@remirepo.net> - 3.0.7-1
- update to 3.0.7

* Mon Jan  1 2018 Remi Collet <remi@remirepo.net> - 3.0.6-1
- Update to 3.0.6

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 3.0.5-2
- rebuild for PHP 7.2.0beta1 new API

* Thu Jun 29 2017 Remi Collet <remi@remirepo.net> - 3.0.5-1
- Update to 3.0.5
- drop patch merged upstream

* Sun Jun 25 2017 Remi Collet <remi@remirepo.net> - 3.0.4-4
- add patch for PHP 7.2 from
  https://github.com/laruence/yaf/pull/358

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 3.0.4-3
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 3.0.4-2
- rebuild for PHP 7.1 new API version

* Thu Sep  1 2016 Remi Collet <remi@fedoraproject.org> - 3.0.4-1
- update to 3.0.4

* Sat Jul  2 2016 Remi Collet <remi@fedoraproject.org> - 3.0.3-1
- update to 3.0.3
- drop patch merged upstream

* Sat Jun 11 2016 Remi Collet <remi@fedoraproject.org> - 3.0.2-3
- add patch for PHP 7.1
  open https://github.com/laruence/yaf/pull/289

* Sun Mar  6 2016 Remi Collet <remi@fedoraproject.org> - 3.0.2-2
- adapt for F24

* Mon Dec 28 2015 Remi Collet <remi@fedoraproject.org> - 3.0.2-1
- update to 3.0.2 (beta, php 7)

* Sun Dec 13 2015 Remi Collet <remi@fedoraproject.org> - 3.0.1-1
- update to 3.0.1 (beta, php 7)

* Tue Oct 27 2015 Remi Collet <remi@fedoraproject.org> - 3.0.0-1
- update to 3.0.0 (php 7)

* Tue Oct 13 2015 Remi Collet <remi@fedoraproject.org> - 3.0.0-0.8.20150914gitaeb6457
- rebuild for PHP 7.0.0RC5 new API version
- new snapshot

* Sun Sep  6 2015 Remi Collet <remi@fedoraproject.org> - 3.0.0-0.7.20150906git63222a2
- new shapshot (changes from 2.3.5)

* Thu Aug 13 2015 Remi Collet <remi@fedoraproject.org> - 3.0.0-0.6.20150813git2dd49ab
- new shapshot

* Fri Jul 24 2015 Remi Collet <remi@fedoraproject.org> - 3.0.0-0.6.20150720git629d412
- ignore 1 failed test on ZTS
- open https://github.com/laruence/php-yaf/issues/180 (1 failed on ZTS)

* Wed Jul 22 2015 Remi Collet <remi@fedoraproject.org> - 3.0.0-0.5.20150720git629d412
- rebuild against php 7.0.0beta2

* Wed Jul  8 2015 Remi Collet <remi@fedoraproject.org> - 3.0.0-0.4.20150701gitfb20f6c
- rebuild against php 7.0.0beta1

* Wed Jun 24 2015 Remi Collet <remi@fedoraproject.org> - 3.0.0-0.3.20150618gita40f01e
- new snapshot
- rebuild for "rh_layout"

* Wed Jun 17 2015 Remi Collet <remi@fedoraproject.org> - 3.0.0-0.2.20150612gita1bd3ac
- rebuild

* Fri Jun 12 2015 Remi Collet <remi@fedoraproject.org> - 3.0.0-0.1.20150612gita1bd3ac
- Update to 3.0.0-dev for PHP 7
- sources from github
- drop runtime dependency on pear, new scriptlets

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 2.3.3-1.1
- Fedora 21 SCL mass rebuild

* Sat Oct 25 2014 Remi Collet <remi@fedoraproject.org> - 2.3.3-1
- Update to 2.3.3

* Tue Aug 26 2014 Remi Collet <rcollet@redhat.com> - 2.3.2-4
- improve SCL build

* Thu Jun 26 2014 Remi Collet <remi@fedoraproject.org> - 2.3.2-3
- upstream patch for PHP 5.6

* Thu Apr 17 2014 Remi Collet <remi@fedoraproject.org> - 2.3.2-2
- add numerical prefix to extension configuration file (php 5.6)

* Thu Jan 09 2014 Remi Collet <remi@fedoraproject.org> - 2.3.2-1
- Update to 2.3.2 (beta)

* Wed Jan 08 2014 Remi Collet <remi@fedoraproject.org> - 2.3.1-1
- Update to 2.3.1 (beta)

* Wed Jan 08 2014 Remi Collet <remi@fedoraproject.org> - 2.3.0-1
- Update to 2.3.0 (beta)
- install doc in pecl doc_dir
- install tests in pecl test_dir
- adapt for SCL
- add missing files from upstream git repo
  https://github.com/laruence/php-yaf/issues/82

* Fri Jan  4 2013 Remi Collet <remi@fedoraproject.org> - 2.2.9-1
- version 2.2.9 (stable)

* Tue Dec 18 2012 Remi Collet <remi@fedoraproject.org> - 2.2.8-1
- version 2.2.8 (stable)

* Mon Nov 19 2012 Remi Collet <remi@fedoraproject.org> - 2.2.7-1
- version 2.2.7 (stable)

* Thu Nov  1 2012 Remi Collet <remi@fedoraproject.org> - 2.2.6-1
- version 2.2.6 (stable)

* Mon Oct 22 2012 Remi Collet <remi@fedoraproject.org> - 2.2.5-1
- version 2.2.5 (stable)
- LICENSE now provided by upstream

* Tue Sep  4 2012 Remi Collet <remi@fedoraproject.org> - 2.2.4-1
- version 2.2.4 (beta)
- initial package
